"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const HybridCryptography_1 = require("./HybridCryptography");
class HandshakeClient extends HybridCryptography_1.HybridCryptography {
    get SessionId() {
        return this.strSessionId;
    }
    constructor() {
        super();
        this.objKeys = { next_pub: "", next_prv: "", created_date: -1 };
        this.strSessionId = "";
    }
    validateResponseSwhsHeader(headers) {
        if (!headers.swhs_sess_id) {
            throw new Error("HANDSHAKE_INVALID: Missing header swhs_sess_id");
        }
        else if (this.strSessionId && this.strSessionId !== headers.swhs_sess_id) {
            throw new Error("HANDSHAKE_INVALID: Session ID mismatch");
        }
    }
    generateHandshake() {
        const date = new Date();
        const rsa = this.createRSAEncrytptionKey(date.getTime().toString());
        this.strSessionId = "";
        this.objKeys = {
            created_date: date.getTime(),
            next_prv: rsa.private_key,
            next_pub: rsa.public_key,
        };
        const aesSet = this.createAESEncryptionKey();
        const encNextPub = this.aesEncrypt(this.objKeys.next_pub, aesSet.key, aesSet.iv);
        return {
            body: {
                is_json: false,
            },
            headers: {
                swhs_action: "handshake_init",
                swhs_iv: aesSet.iv.toString("base64"),
                swhs_key: aesSet.key.toString("base64"),
                swhs_next: encNextPub,
                swhs_sess_id: "",
            },
        };
    }
    encryptRequest(body) {
        if (!body) {
            throw new Error("BODY_INVALID");
        }
        else if (!this.objKeys.next_pub) {
            throw new Error("Next public request key is not set!");
        }
        const result = this.hybridEncrypt(body, this.objKeys.next_pub);
        this.objKeys.next_prv = result.next_prv;
        this.objKeys.created_date = result.created_date;
        return {
            body: {
                enc_body: result.encData,
                is_json: result.isJson,
            },
            headers: {
                swhs_action: "request_basic",
                swhs_iv: result.iv,
                swhs_key: result.key,
                swhs_next: result.nextPub,
                swhs_sess_id: this.strSessionId,
            },
        };
    }
    handleHandshakeResponse(headers, body) {
        console.dir(body);
        if (!this.strSessionId && headers.swhs_sess_id) {
            this.strSessionId = headers.swhs_sess_id;
        }
        return this.decryptResponse(headers, body);
    }
    decryptResponse(headers, body) {
        this.validateResponseSwhsHeader(headers);
        const decrypted = this.hybridDecrypt(body, headers.swhs_next, this.objKeys.next_prv, this.objKeys.created_date.toString(), headers.swhs_key, headers.swhs_iv);
        this.objKeys.next_pub = decrypted.nextPub;
        return decrypted.data;
    }
}
exports.HandshakeClient = HandshakeClient;
//# sourceMappingURL=HandshakeClient.js.map