"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const HybridCryptography_1 = require("./HybridCryptography");
class HandshakeServer extends HybridCryptography_1.HybridCryptography {
    constructor() {
        super();
    }
    handleHandshakeRequest(headers) {
        if (headers.swhs_sess_id === "") {
            throw new Error("SESSION_ID_INVALID");
        }
        else if (headers.swhs_action !== "handshake_init") {
            throw new Error("HANDSHAKE_INVALID_INIT");
        }
        else if (headers.swhs_iv.length < 10) {
            throw new Error("HANDSHAKE_AES_IV_INVALID");
        }
        const responsePubKey = this.aesDecrypt(headers.swhs_next, false, headers.swhs_key, headers.swhs_iv);
        const result = this.encryptResponse(headers.swhs_sess_id, { status: "ok" }, responsePubKey);
        result.headers.swhs_action = "handshake_response";
        return result;
    }
    decryptRequest(headers, body, nextPrv, passphrase) {
        const decrypted = this.hybridDecrypt(body, headers.swhs_next, nextPrv, passphrase, headers.swhs_key, headers.swhs_iv);
        return {
            body: decrypted.data,
            next_pub: decrypted.nextPub,
        };
    }
    encryptResponse(swhsSessionId, body, rsaPub) {
        if (!rsaPub) {
            throw new Error("PUBLIC_KEY_INVALID");
        }
        else if (!body) {
            throw new Error("BODY_INVALID");
        }
        const result = this.hybridEncrypt(body, rsaPub);
        return {
            body: {
                enc_body: result.encData,
                is_json: result.isJson,
            },
            decrypt: {
                created_date: result.created_date,
                next_prv: result.next_prv,
            },
            headers: {
                swhs_action: "encrypt_response",
                swhs_iv: result.iv,
                swhs_key: result.key,
                swhs_next: result.nextPub,
                swhs_sess_id: swhsSessionId,
            },
        };
    }
}
exports.HandshakeServer = HandshakeServer;
//# sourceMappingURL=HandshakeServer.js.map