/// <reference types="node" />
import { BinaryLike } from "crypto";
export declare type Algorithms = "aes-128-cbc";
export declare type RsaSizes = 512 | 1024;
export interface SwhsHeaders {
    swhs_action: string;
    swhs_iv: string;
    swhs_key: string;
    swhs_next: string;
    swhs_sess_id: string;
}
export interface SwhsBody {
    enc_body?: string;
    is_json: boolean;
}
export declare class HybridCryptography {
    protected aesEncrypt(data: BinaryLike, key: Buffer | string, iv: Buffer | string, algorithm?: Algorithms): string;
    protected aesDecrypt(encData: string, isJson: boolean | undefined, key: Buffer | string, iv: Buffer | string, algorithm?: Algorithms): string | Buffer;
    protected createAESEncryptionKey(algorithm?: Algorithms): {
        key: Buffer;
        iv: Buffer;
    };
    protected createRSAEncrytptionKey(passphrase: string, algorithm?: Algorithms, modulusLength?: RsaSizes): {
        private_key: string;
        public_key: string;
    };
    protected hybridDecrypt(body: SwhsBody, rsaNextPub: string, privateKey: Buffer | string, passphrase: string, key: Buffer | string, iv: Buffer | string, algorithm?: Algorithms): {
        data: string | Buffer | undefined;
        nextPub: string | Buffer;
    };
    protected hybridEncrypt(data: BinaryLike | object, rsaPub: Buffer | string, modulusLength?: RsaSizes, algorithm?: Algorithms): {
        created_date: number;
        encData: string;
        isJson: boolean;
        iv: string;
        key: string;
        nextPub: string;
        next_prv: string;
    };
}
