"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const crypto_1 = __importStar(require("crypto"));
const SwhsHeaderRules = {
    swhs_action: {
        maxlen: 50,
    },
};
class HybridCryptography {
    aesEncrypt(data, key, iv, algorithm = "aes-128-cbc") {
        if (typeof key === "string") {
            key = Buffer.from(key, "base64");
        }
        if (typeof iv === "string") {
            iv = Buffer.from(iv, "base64");
        }
        const cipher = crypto_1.default.createCipheriv(algorithm, key, iv);
        const encData = cipher.update(data);
        return Buffer.concat([encData, cipher.final()])
            .toString("base64");
    }
    aesDecrypt(encData, isJson = false, key, iv, algorithm = "aes-128-cbc") {
        if (typeof key === "string") {
            key = Buffer.from(key, "base64");
        }
        if (typeof iv === "string") {
            iv = Buffer.from(iv, "base64");
        }
        const encDataBuff = Buffer.from(encData, "base64");
        const decipher = crypto_1.default.createDecipheriv(algorithm, key, iv);
        const decDataBuff = decipher.update(encDataBuff);
        let decData = Buffer.concat([decDataBuff, decipher.final()]).toString();
        if (isJson) {
            decData = JSON.parse(decData);
        }
        return decData;
    }
    createAESEncryptionKey(algorithm = "aes-128-cbc") {
        let size;
        switch (algorithm) {
            case "aes-128-cbc":
                size = 16;
                break;
            default:
                throw new Error("Algorithm not supported");
        }
        return { key: crypto_1.default.randomBytes(size), iv: crypto_1.default.randomBytes(size) };
    }
    createRSAEncrytptionKey(passphrase, algorithm = "aes-128-cbc", modulusLength = 512) {
        const keys = crypto_1.generateKeyPairSync("rsa", {
            modulusLength,
            privateKeyEncoding: {
                cipher: algorithm,
                format: "pem",
                passphrase: passphrase.toString(),
                type: "pkcs8",
            },
            publicKeyEncoding: {
                format: "pem",
                type: "spki",
            },
        });
        return {
            private_key: keys.privateKey,
            public_key: keys.publicKey,
        };
    }
    hybridDecrypt(body, rsaNextPub, privateKey, passphrase, key, iv, algorithm = "aes-128-cbc") {
        try {
            if (typeof key === "string") {
                key = Buffer.from(key, "base64");
            }
            key = crypto_1.default.privateDecrypt({ key: privateKey, passphrase }, key);
            if (typeof iv === "string") {
                iv = Buffer.from(iv, "base64");
            }
            iv = crypto_1.default.privateDecrypt({ key: privateKey, passphrase }, iv);
            const nextPub = this.aesDecrypt(rsaNextPub, false, key, iv);
            let data;
            if (body.enc_body !== undefined || body.enc_body !== "") {
                data = this.aesDecrypt(body.enc_body, body.is_json, key, iv);
            }
            return { data, nextPub };
        }
        catch (err) {
            throw new Error(err.message);
        }
    }
    hybridEncrypt(data, rsaPub, modulusLength = 512, algorithm = "aes-128-cbc") {
        try {
            let isJson = false;
            if (typeof data === "object") {
                isJson = true;
                data = JSON.stringify(data);
            }
            const date = new Date();
            const rsaKeys = this.createRSAEncrytptionKey(date.getTime().toString(), algorithm, modulusLength);
            const aesSet = this.createAESEncryptionKey(algorithm);
            const encData = this.aesEncrypt(data, aesSet.key, aesSet.iv);
            const nextPub = this.aesEncrypt(rsaKeys.public_key, aesSet.key, aesSet.iv);
            const iv = crypto_1.default.publicEncrypt(rsaPub, aesSet.iv).toString("base64");
            const key = crypto_1.default.publicEncrypt(rsaPub, aesSet.key).toString("base64");
            return {
                created_date: date.getTime(),
                encData,
                isJson, iv, key, nextPub,
                next_prv: rsaKeys.private_key,
            };
        }
        catch (err) {
            throw new Error(err.message);
        }
    }
}
exports.HybridCryptography = HybridCryptography;
//# sourceMappingURL=HybridCryptography.js.map